#!/bin/sh
#**************************************************
# Copyright (c) 2011 Cisco Systems, Inc.
# All rights reserved.
#**************************************************

#---------------------------------------------------------------#
# write log entry
#---------------------------------------------------------------#
log()
{
  case $1 in
    0) pri="local0.error"
       descr="error:[$PROG_NAME]"
       ;;
    1) pri="local0.warning"
       descr="warning:[$PROG_NAME]"
       ;;
    2) pri="local0.notice"
       descr="notice:[$PROG_NAME]"
       ;;
    3) pri="local0.info"
       descr="info:[$PROG_NAME]"
       ;;
    *) pri="local0.debug" # 4 or more is debug
       descr="debug:[$PROG_NAME]"
       ;;
  esac

  logger -p $pri $descr "$2"
}

#---------------------------------------------------------------#
#---------------------------------------------------------------#
backupFileSystem()
{
  log 3 "CDA $PATCHBUILD patch $PATCHVER backupFileSystem() INVOKED"
  mkdir $FILESYSTEMDIR.bak 2>&1 | logger -p local0.info
  for i in `find $FILESYSTEMDIR` ; do
    if [ -f $i ] ; then
      installedfile=`echo $i | sed -e "s|$FILESYSTEMDIR||g"`
      if  [ -f $installedfile ] ; then
        log 3 "Taking backup of patch file: $installedfile "
        cp -pf --parents $installedfile $FILESYSTEMDIR.bak/ 2>&1 | logger -p local0.info
      else
        log 3 "Not backing up new file: $installedfile"
      fi
    fi
  done
}

#---------------------------------------------------------------#
#---------------------------------------------------------------#
installFileSystem()
{
  rm -rf /var/tmp/carspatch
  mkdir -p /var/tmp/carspatch
  log 3 "CDA $PATCHBUILD patch $PATCHVER installFileSystem() INVOKED"
  cd $FILESYSTEMDIR
  for i in `find $FILESYSTEMDIR` ; do
    ISCARS=`echo $i | grep -c "/opt/system"`
    if [ -f $i ]; then
      FILESOURCE=`echo $i |  sed "s|$FILESYSTEMDIR/||g"`
      if [ $ISCARS -eq 1 ] ; then
         echo "Delaying ADEOS update $i until end of CDA patch..." | logger -p local0.info
         cp -rpf --parents $FILESOURCE /var/tmp/carspatch
      else
         log 3 "Updating patched file: $i "
         cp -rpf --parents $FILESOURCE / 2>&1 | logger -p local0.info
      fi
    fi
  done
  rm -rf $CDA_HOME/appsrv/apache-tomcat/work/Catalina/localhost/admin/org/apache/jsp 2>&1 | logger -p local0.info
}

#---------------------------------------------------------------#
# This is only required if the version in the jar filenames
# in the workspace are something other the target patch host.
# This will not be the case for the official patch built by
# the RE folks, but it may be requied if we're testing from 
# a private workspace where jar versions are 1.0-DST-SNAPSHOT
#---------------------------------------------------------------#
moveJarFilenames()
{
    echo "move Jar File Names" 
}
 
#---------------------------------------------------------------#
#---------------------------------------------------------------#
postInstall()
{
    echo "post install"
}

#---------------------------------------------------------------#
#---------------------------------------------------------------#
deleteFiles()
{
    echo "delete apache tomcat work files"
    rm -rf /opt/CSCOcda/appsrv/apache-tomcat-6.0.29/work
}

updateADEOS()
{
    echo "update ADEOS"
}

changeConfigurationDatabaseSchema()
{
  echo "Configuration database schema changes"
  /opt/CSCOcda/bin/sqlite3 /opt/CSCOcda/db/configuration.db.sqlite "INSERT OR IGNORE INTO settings (key,val) VALUES ('NTLMv2','0');"
}

#################################
# MAIN
#################################

PROG_NAME=`basename $0`
PATCHDIR=`dirname $0`
FILESYSTEMDIR=$PATCHDIR/filesystem
INSTALLDIRS=`cat $PATCHDIR/installfolders`
CDA_HOME=/opt/CSCOcda
PATCHBUILD="1.0.0.011"
PATCHVER=1
export CDA_HOME PATCHBUILD PATCHVER

echo "CDA Patch Install Test"

log 3 "CDA Patch Install Test"
log 3 "STARTING PATCH INSTALL SCRIPT. PATCHDIR: $PATCHDIR INSTALLDIRS: $INSTALLDIRS"
# Stop the application - Add script to stop your application here if required
cd $cda_HOME && $CDA_HOME/bin/cdacontrol.sh stop

# Backup the filesystem contents
backupFileSystem

# Install filesystem contents from patch
installFileSystem 

# This next line handled moving jar file names with SNAPSHOT
moveJarFilenames

# Delete any files that are not deprecated with this patch
deleteFiles

# Make configuration database schema chages
changeConfigurationDatabaseSchema

# Run any post install steps required before startup
postInstall

# Start the application- Add script to start your application here if required
cd $CDA_HOME && $CDA_HOME/bin/cdacontrol.sh start

# This patch includes ADEOS updates
updateADEOS

log 3 "CDA PATCH $PATCHBUILD INSTALL COMPLETED"
