#!/bin/sh
#**************************************************
# Copyright (c) 2011 Cisco Systems, Inc.
# All rights reserved.
#**************************************************

#---------------------------------------------------------------#
# write log entry
#---------------------------------------------------------------#
log()
{
  case $1 in
    0) pri="local0.error"
       descr="error:[$PROG_NAME]"
       ;;
    1) pri="local0.warning"
       descr="warning:[$PROG_NAME]"
       ;;
    2) pri="local0.notice"
       descr="notice:[$PROG_NAME]"
       ;;
    3) pri="local0.info"
       descr="info:[$PROG_NAME]"
       ;;
    *) pri="local0.debug" # 4 or more is debug
       descr="debug:[$PROG_NAME]"
       ;;
  esac

  logger -p $pri $descr "$2"
}

#---------------------------------------------------------------#
#---------------------------------------------------------------#
restoreFileSystem()
{
  rm -rf /var/tmp/carspatch
  mkdir -p /var/tmp/carspatch
  cd $FILESYSTEMDIR.bak
  for i in `find $FILESYSTEMDIR` ; do
    if [ -f $i ] ; then
      installedfile=`echo $i | sed -e "s|$FILESYSTEMDIR||g"`
      if [ -f "$FILESYSTEMDIR.bak/$installedfile" ] ;then
        FILESOURCE=`echo ${FILESYSTEMDIR}.bak${installedfile} | sed "s|$FILESYSTEMDIR.bak/||g"`
        ISCARS=`echo $i | grep -c "/opt/system"`
        if [ $ISCARS -eq 1 ] ; then
           echo "Delaying cars restore $i till end of patch..." | logger -p local0.info
            cp -rpvf --parents $FILESOURCE /var/tmp/carspatch | logger -p local0.info
         else
            rm -rf $installedfile 2>&1 | logger -p local0.info
            log 3 "Restoring file: $installedfile from backup"
            cp -rpf --parents  $FILESOURCE / 2>&1 | logger -p local0.info
         fi
      else
        log 3 "Not restoring new file: $FILESYSTEMDIR.bak$installedfile from backup"
      fi
    fi
  done
}

#---------------------------------------------------------------#
#---------------------------------------------------------------#
deleteFiles()
{
  echo "deleteFiles"
  rm -rf /opt/CSCOcda/appsrv/apache-tomcat-6.0.29/work
}

updateADEOS()
{
  echo "updateADEOS"
}

changeConfigurationDatabaseSchema()
{
  echo "Configuration database schema changes"
  /opt/CSCOcda/bin/sqlite3 /opt/CSCOcda/db/configuration.db.sqlite "DELETE FROM settings WHERE key='NTLMv2';"
}

#################################
# MAIN
#################################

PROG_NAME=`basename $0`
PATCHDIR=`dirname $0`
FILESYSTEMDIR=$PATCHDIR/filesystem
INSTALLDIRS=`cat $PATCHDIR/installfolders`
CDA_HOME=/opt/CSCOcda
PATCHBUILD="1.0.0.0"
PATCHVER=1
export CDA_HOME PATCHBUILD PATCHVER

log 3 "Starting patch uninstall script. PATCHDIR: $PATCHDIR  INSTALLDIRS: $INSTALLDIRS"

# Stop the application - Add script to stop your application here if required
cd $CDA_HOME && $CDA_HOME/bin/cdacontrol.sh stop

# Restore filesystem contents from saved backup dir
restoreFileSystem

# Delete any new files introduced in patch
deleteFiles

# Make configuration database schema chages
changeConfigurationDatabaseSchema

#Start the application- Add script to start  your application here if required
cd $CDA_HOME && $CDA_HOME/bin/cdacontrol.sh start

updateADEOS
